@@ -1,4 +1,4 @@
-from pomdp_py.utils import util
+import pomdp_py.utils as util
 
 # Framework
 from pomdp_py.framework.basics import *
@@ -6,7 +6,7 @@ from pomdp_py.framework.oopomdp import *
 from pomdp_py.framework.planner import *
 
 # Representations
-from pomdp_py.representations.distribution.particles import Particles
+from pomdp_py.representations.distribution.particles import Particles, WeightedParticles
 from pomdp_py.representations.distribution.histogram import Histogram
 from pomdp_py.representations.distribution.gaussian import Gaussian
 from pomdp_py.representations.belief.histogram import update_histogram_belief
@@ -20,10 +20,10 @@ from pomdp_py.algorithms.value_function import value, qvalue, belief_update
 from pomdp_py.algorithms.pomcp import POMCP
 from pomdp_py.algorithms.po_rollout import PORollout
 from pomdp_py.algorithms.po_uct import POUCT, QNode, VNode, RootVNode,\
-    RolloutPolicy, RandomRollout, print_preferred_actions, print_tree,\
-    tree_stats, ActionPrior
+    RolloutPolicy, RandomRollout, ActionPrior
 from pomdp_py.algorithms.bsp.blqr import BLQR
-from pomdp_py.algorithms.visual import visual
+from pomdp_py import visual
 
-# Templates
+# Templates & Utilities
 from pomdp_py.utils.templates import *
+from pomdp_py.utils.debugging import TreeDebugger
